@@ -5,13 +5,22 @@ var jsonSchemaTest = require('json-schema-test');
 var defineKeywords = require('..');
 
 var ajvs = [
-  defineKeywords(getAjv(),
-    ['switch', 'patternRequired', 'formatMinimum', 'formatMaximum',
-      'uniqueItemProperties', 'if', 'prohibited', 'deepRequired', 'deepProperties', 'select']),
+  defineKeywords(getAjv(), [
+    'allRequired',
+    'anyRequired',
+    'deepProperties',
+    'deepRequired',
+    'formatMaximum',
+    'formatMinimum',
+    'patternRequired',
+    'prohibited',
+    'select',
+    'switch',
+    'uniqueItemProperties'
+  ]),
   defineKeywords(getAjv()),
   defineKeywords(getAjv(true)),
-  defineKeywords(getAjvNoMeta()),
-  defineKeywords(getAjvV5())
+  defineKeywords(getAjvNoMeta())
 ];
 
 
@@ -45,20 +54,3 @@ function getAjvNoMeta() {
     validateSchema: false
   });
 }
-
-
-function getAjvV5() {
-  var ajv = new Ajv({
-    $data: true,
-    meta: false,
-    unknownFormats: 'ignore'
-  });
-
-  ajv.addMetaSchema(require('ajv/lib/refs/json-schema-draft-04.json'));
-
-  var metaSchema = require('ajv/lib/refs/json-schema-v5.json');
-  ajv.addMetaSchema(metaSchema);
-  ajv._opts.defaultMeta = metaSchema.id;
-
-  return ajv;
-}
